﻿using GalaSoft.MvvmLight;
using GalaSoft.MvvmLight.Messaging;
using GalaSoft.MvvmLight.Command;
using Violet.Dialog;

namespace ModalDialogDemo.ViewModel
{
    /// <summary>
    /// This class contains properties that a View can data bind to.
    /// <para>
    /// Use the <strong>mvvminpc</strong> snippet to add bindable properties to this ViewModel.
    /// </para>
    /// <para>
    /// You can also use Blend to data bind with the tool's support.
    /// </para>
    /// <para>
    /// See http://www.galasoft.ch/mvvm/getstarted
    /// </para>
    /// </summary>
    public class ADialogViewModel : ViewModelBase
    {
        public delegate void SaveHandler();
        public event SaveHandler SaveEvent;

        public RelayCommand SaveCommand { get; set; }
        public RelayCommand CancelCommand { get; set; }

        /// <summary>
        /// Initializes a new instance of the ADialogViewModel class.
        /// </summary>
        public ADialogViewModel()
        {
            SaveCommand = new RelayCommand(() =>
            {
                if (SaveEvent != null)
                {
                    SaveEvent();
                }
                Messenger.Default.Send<NotificationMessage>(new NotificationMessage(this, ""), Constants.Dialog_Close);
                
            });

            CancelCommand = new RelayCommand(() =>
            {
                Messenger.Default.Send<NotificationMessage>(new NotificationMessage(this, ""), Constants.Dialog_Close);
            });
        }
    }
}