﻿using GalaSoft.MvvmLight;
using GalaSoft.MvvmLight.Command;
using GalaSoft.MvvmLight.Messaging;
using Violet.Dialog;

namespace ModalDialogDemo.ViewModel
{
    /// <summary>
    /// This class contains properties that a View can data bind to.
    /// <para>
    /// Use the <strong>mvvminpc</strong> snippet to add bindable properties to this ViewModel.
    /// </para>
    /// <para>
    /// You can also use Blend to data bind with the tool's support.
    /// </para>
    /// <para>
    /// See http://www.galasoft.ch/mvvm/getstarted
    /// </para>
    /// </summary>
    public class BoardViewModel : ViewModelBase
    {
        private int _count;
        public int Count
        {
            get { return _count; }
            set { _count = value; RaisePropertyChanged("Count"); }
        }

        private int _countA;
        private int _countB;

        private string _message;
        public string Message
        {
            get { return _message; }
            set { _message = value; RaisePropertyChanged("Message"); }
        }

        public RelayCommand ShowACommand { get; set; }
        public RelayCommand ShowBCommand { get; set; }

        private void refreshBoardAfterA()
        {
            Message = "A 执行了 ";
            _countA++;
            Count = _countA;
        }

        private void refreshBoardAfterB()
        {
            Message = "B 执行了 ";
            _countB++;
            Count = _countB;
        }

        /// <summary>
        /// Initializes a new instance of the BoardViewModel class.
        /// </summary>
        public BoardViewModel()
        {
            ShowACommand = new RelayCommand(() =>
            {
                ADialogViewModel a = new ADialogViewModel();
                a.SaveEvent += refreshBoardAfterA;
                DialogParam param = new DialogParam();
                param.Content = a;
                param.Title = "A";
                param.Height = 200;
                param.Width = 200;
                param.Opcity = 0.8;

                Messenger.Default.Send<DialogParam>(param, Constants.Dialog_Open);
            });

            ShowBCommand = new RelayCommand(() =>
            {
                BDialogViewModel b = new BDialogViewModel();
                b.SaveEvent += refreshBoardAfterB;
                DialogParam param = new DialogParam();
                param.Content = b;
                param.Title = "B";
                Messenger.Default.Send<DialogParam>(param, Constants.Dialog_Open);
            });
        }

        
    }
}