﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using GalaSoft.MvvmLight;
using GalaSoft.MvvmLight.Command;
using GalaSoft.MvvmLight.Messaging;

namespace Violet.Dialog.ViewModel
{
    /// <summary>
    /// This class contains properties that a View can data bind to.
    /// <para>
    /// Use the <strong>mvvminpc</strong> snippet to add bindable properties to this ViewModel.
    /// </para>
    /// <para>
    /// You can also use Blend to data bind with the tool's support.
    /// </para>
    /// <para>
    /// See http://www.galasoft.ch/mvvm/getstarted
    /// </para>
    /// </summary>
    public class DialogViewModel : ViewModelBase, IDisposable
    {
        #region Properties
        private string _visibility = "Collapsed";
        public string Visibility
        {
            set { _visibility = value; RaisePropertyChanged("Visibility"); }
            get { return _visibility; }
        }

        private double _opcity;
        private double _defaultOpcity = 0.5;
        public double Opcity
        {
            set { _opcity = value; RaisePropertyChanged("Opcity"); }
            get { return _opcity; }
        }

        private string _title { get; set; }
        public string Title
        {
            set { _title = value; RaisePropertyChanged("Title"); }
            get { return _title; }
        }

        private int _defaultWidth = 500;
        private int _defaultHeight = 300;
        private int _width;
        public int Width
        {
            set { _width = value; RaisePropertyChanged("Width"); }
            get { return _width; }
        }

        private int _height;
        public int Height
        {
            set { _height = value; RaisePropertyChanged("Height"); }
            get { return _height; }
        }

        private object _content { get; set; }
        public object Content
        {
            get { return _content; }
            set { _content = value; RaisePropertyChanged("Content"); }
        }

        #endregion

        public RelayCommand OKCommand { get; set; }
        public RelayCommand CloseCommand { get; set; }

        /// <summary>
        /// Initializes a new instance of the DialogViewModel class.
        /// </summary>
        public DialogViewModel()
        {
            //Messenger.Default.Send(
            Messenger.Default.Register<DialogParam>(this, Constants.Dialog_Open, m =>
            {
                Visibility = "Visible";
                Opcity = m.Opcity != 0 ? m.Opcity : _defaultOpcity;
                Height = m.Height != 0 ? m.Height : _defaultHeight;
                Width = m.Width != 0 ? m.Width : _defaultWidth;
                Title = m.Title;
                Content = m.Content;
            });

            Messenger.Default.Register<NotificationMessage>(this, Constants.Dialog_Close, m =>
            {
                Visibility = "Collapsed";
                ((ViewModelBase)Content).Dispose();
            });

            CloseCommand = new RelayCommand(() =>
            {
                Visibility = "Collapsed";
                ((ViewModelBase)Content).Dispose();
            });
        }

        public void Dispose()
        {
            Messenger.Default.Unregister<NotificationMessage>(this);
            Messenger.Default.Unregister<DialogParam>(this);
        }

    }
}
